@@ -102,7 +102,39 @@ CLI_COMMANDS_HELP = {
         'subnet': """Get subnet plan layout of the applcation.\n
                 """,
 
-    }
+    },
+    'package': {
+        'build': """Build a distrubutabkle package, and adds it to artifact store.\n
+                ** Tips: 1) ... 2) ...\n
+                """,
+        'list': """Return the list of packages in a context.\n
+                ** Tips: 1) To limit the list to the owned/overriden packages only, use the '--uninherited' option. This will return only the context specific packages.
+                """,
+        'get': """Get a package from artifact store.\n
+                ** Tips: 1) ... 2) ...\n
+                KEY: The identifier of the package. It may also be provided using the '--key' option.\n
+                """,
+        'delete': """Delete a package from a context.\n
+                ** Tips: 1) The inherited package cannot be deleted. The context must be the owner of the secret or a not found error will be returned. 2) Multiple packages may be deleted at once using the '--input' option.\n
+                KEY: The identifier of the package to be deleted. It may also be provided using the '--key' option.\n
+                """,
+        },
+    'release': {
+        'create': """Create a deployment release, and adds it to artifact store.\n
+                ** Tips: 1) ... 2) ...\n
+                """,
+        'list': """Return the list of releases in a context.\n
+                ** Tips: 1) To limit the list to the owned/overriden releases only, use the '--uninherited' option. This will return only the context specific releases.
+                """,
+        'get': """Get a release from artifact store.\n
+                ** Tips: 1) ... 2) ...\n
+                KEY: The identifier of the release. It may also be provided using the '--key' option.\n
+                """,
+        'delete': """Delete a release from a context.\n
+                ** Tips: 1) The inherited release cannot be deleted. The context must be the owner of the secret or a not found error will be returned. 2) Multiple releases may be deleted at once using the '--input' option.\n
+                KEY: The identifier of the release to be deleted. It may also be provided using the '--key' option.\n
+                """,
+        },
 }
 
 CLI_COMMANDS_SHORT_HELP = {
@@ -133,10 +165,10 @@ CLI_COMMANDS_SHORT_HELP = {
         'render': "Render templates using parameters in a context.",
     },
     'package': {
-        'list': "List packages built for the application.",
-        'create': "Create a build package for the application.",
-        'get': "Download an application build package.",
-        'delete': "Delete a build package from the application.",
+        'list': "List packages built for the application available on arctifact store.",
+        'build': "Build a distributable package for the application.",
+        'get': "Download a build package from arctifact store.",
+        'delete': "Delete a build package from arctifact store.",
     },
     'release': {
         'list': "List deployment releases for the application.",
@@ -220,7 +252,16 @@ CLI_PARAMETERS_HELP = {
     'network': {
         'subnet_layout_mode': "Select the subnet plan layout mode.",
     
-    }
+    },
+    'package': {
+        'key': "The key of the package. See KEY argument for more details.",
+
+    },
+    'release': {
+        'key': "The key of the release. See KEY argument for more details.",
+
+    },
+
 
 
 }
