@@ -1,5 +1,6 @@
 
 import os
+import enum
 # from pathlib import Path
 # import shutils
 from .logger import Logger
@@ -13,6 +14,38 @@ from .exceptions import DSOException
 #             shutils.rmtree(path)
 
 
+class SIZE_UNIT(enum.Enum):
+    AUTO = 0
+    BYTES = 1
+    KB = 2
+    MB = 3
+    GB = 4
+    TB = 5
+
+def convert_file_size_unit(size_in_bytes, unit=SIZE_UNIT.AUTO, precision=2):
+    if unit == SIZE_UNIT.AUTO:
+        if size_in_bytes < 1e3:
+            unit = SIZE_UNIT.BYTES
+        elif size_in_bytes < 1e6:
+            unit = SIZE_UNIT.KB
+        elif size_in_bytes < 1e9:
+            unit = SIZE_UNIT.GB
+        else:
+            unit = SIZE_UNIT.TB
+
+    if unit == SIZE_UNIT.BYTES:
+        return str(size_in_bytes) + 'B'
+    if unit == SIZE_UNIT.KB:
+        return str(round(size_in_bytes/1024, precision)) + 'KB'
+    elif unit == SIZE_UNIT.MB:
+        return str(round(size_in_bytes/(1024*1024), precision)) + 'MB'
+    elif unit == SIZE_UNIT.GB:
+        return str(round(size_in_bytes/(1024*1024*1024), precision)) + 'GB'
+    elif unit == SIZE_UNIT.GB:
+        return str(round(size_in_bytes/(1024*1024*1024*1024), precision)) + 'TB'
+    else:
+        raise NotImplementedError
+
 def is_binary_file(filename):
     """ 
     Return true if the given filename appears to be binary.
